@@ -44,9 +44,9 @@ def runserver(host, port):
 def sync_customers():
     """Udpate customers from CRM"""
     LOGS.logger.info("Sync customers from CRM -- START")
-    products = Product.all()
+    products = ["business_access", "business_plus", "airfiber"]
     for product in products:
-        customers = core.get_customers_crm(product.name)
+        customers = core.get_customers_crm(product)
         for customer in customers:
             name = customer['ident'].lower()
             product_name = customer['produit_nom']
